aboutsummaryrefslogtreecommitdiffstats
path: root/csit/drools-pdp/plans
diff options
context:
space:
mode:
Diffstat (limited to 'csit/drools-pdp/plans')
-rwxr-xr-xcsit/drools-pdp/plans/setup.sh10
1 files changed, 6 insertions, 4 deletions
diff --git a/csit/drools-pdp/plans/setup.sh b/csit/drools-pdp/plans/setup.sh
index 987c453c..f08126ec 100755
--- a/csit/drools-pdp/plans/setup.sh
+++ b/csit/drools-pdp/plans/setup.sh
@@ -1,7 +1,7 @@
#!/bin/bash
# ============LICENSE_START=======================================================
# Copyright 2017-2021 AT&T Intellectual Property. All rights reserved.
-# Modifications Copyright 2021-2022 Nordix Foundation.
+# Modifications Copyright 2021-2023 Nordix Foundation.
# ================================================================================
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
@@ -30,16 +30,18 @@ source "${SCRIPTS}"/get-versions.sh
docker-compose -f "${SCRIPTS}"/docker-compose-all.yml up -d drools
POLICY_DROOLS_IP=$(get-instance-ip.sh drools)
+POLICY_DROOLS_PORT=30217
MARIADB_IP=$(get-instance-ip.sh mariadb)
echo DROOLS IP IS "${POLICY_DROOLS_IP}"
echo MARIADB IP IS "${MARIADB_IP}"
-# wait for the app to start up - looking for telemetry service on port 9696
-"${SCRIPTS}"/wait_for_port.sh "${POLICY_DROOLS_IP}" 9696
+# wait for the app to start up - looking for telemetry service on port 30216 forwarded from 9696
+"${SCRIPTS}"/wait_for_rest.sh localhost 30216
# give enough time for the controllers to come up
sleep 15
ROBOT_VARIABLES=""
-ROBOT_VARIABLES="${ROBOT_VARIABLES}-v POLICY_DROOLS_IP:${POLICY_DROOLS_IP}"
+ROBOT_VARIABLES="${ROBOT_VARIABLES} -v POLICY_DROOLS_IP:${POLICY_DROOLS_IP}"
+ROBOT_VARIABLES="${ROBOT_VARIABLES} -v POLICY_DROOLS_PORT:${POLICY_DROOLS_PORT}"